/* -*- c++ -*- */
/*
 * Copyright 2011 Alexandru Csete OZ9AEC.
 *
 * Gqrx is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * Gqrx is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Gqrx; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */
#ifndef ARISSATTLM_H
#define ARISSATTLM_H

#include <QLabel>
#include <QWidget>
#include <QByteArray>
#include "tlm/arissat/ss_types_common.h"


namespace Ui {
    class ArissatTlm;
}


/*! \brief Disaply widget for ARISSat-1 telemetry.
 *
 * REF: The Radioskaf-V / ARISSat-1 Telemetry Format Version 1.1
 *      by Douglas Quagliana and Jerry Zdenek
 */
class ArissatTlm : public QWidget
{
    Q_OBJECT

public:
    explicit ArissatTlm(QWidget *parent = 0);
    ~ArissatTlm();

    void processData(QByteArray &data);

private:
    void createPptLabels();
    void updateMissionData(ss_telem_t &tlm);
    void updateIhuTemps(ss_telem_t &tlm);
    void updateBattery(ss_telem_t &tlm);
    void updatePower(ss_telem_t &tlm);
    void updatePpt(ss_telem_t &tlm);

private:
    Ui::ArissatTlm *ui;     /*! UI generated by Qt Designer. */

    QLabel *pptEnergy[PPT_COUNT];    /*! Panel energy for PPT 1..6 */
    QLabel *pptVolt[PPT_COUNT];      /*! Panel voltage for PPT 1..6 */
    QLabel *pptAmp[PPT_COUNT];       /*! Panel current for PPT 1..6 */
    QLabel *pptTempPanel[PPT_COUNT]; /*! Panel temperature for PPT 1..6 */
    QLabel *pptTempInd[PPT_COUNT];   /*! Inductor temperature for PPT 1..6 */
    QLabel *pptTempDiode[PPT_COUNT]; /*! Diode temperature for PPT 1..6 */
    QLabel *pptTempFet[PPT_COUNT];   /*! FET temperature for PPT 1..6 */
    QLabel *pptPwm[PPT_COUNT];       /*! PWM setpoint. */
    QLabel *pptAge[PPT_COUNT];       /*! Telemetry age. */
    QLabel *pptCorrupt[PPT_COUNT];   /*! number of corrupt packets */

    QChar deg;  /*! Convenience character for degree. */

    u32 frameCounter;
};

#endif // ARISSATTLM_H
